<?php

namespace B2buy\Customprice\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use B2buy\Customprice\Http\Requests\CustompriceRequest;
use B2buy\Customprice\Interfaces\CustompriceRepositoryInterface;
use B2buy\Customprice\Models\Customprice;

/**
 * Resource controller class for customprice.
 */
class CustompriceResourceController extends BaseController
{

    /**
     * Initialize customprice resource controller.
     *
     * @param type CustompriceRepositoryInterface $customprice
     *
     * @return null
     */
    public function __construct(CustompriceRepositoryInterface $customprice)
    {
        parent::__construct();
        $this->repository = $customprice;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Customprice\Repositories\Criteria\CustompriceResourceCriteria::class);
    }

    /**
     * Display a list of customprice.
     *
     * @return Response
     */
    public function index(CustompriceRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\B2buy\Customprice\Repositories\Presenter\CustompricePresenter::class)
                ->$function();
        }

        $customprices = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('customprice::customprice.names'))
            ->view('customprice::customprice.index', true)
            ->data(compact('customprices', 'view'))
            ->output();
    }

    /**
     * Display customprice.
     *
     * @param Request $request
     * @param Model   $customprice
     *
     * @return Response
     */
    public function show(CustompriceRequest $request, Customprice $customprice)
    {

        if ($customprice->exists) {
            $view = 'customprice::customprice.show';
        } else {
            $view = 'customprice::customprice.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('customprice::customprice.name'))
            ->data(compact('customprice'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new customprice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CustompriceRequest $request)
    {

        $customprice = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('customprice::customprice.name')) 
            ->view('customprice::customprice.create', true) 
            ->data(compact('customprice'))
            ->output();
    }

    /**
     * Create new customprice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CustompriceRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $customprice                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('customprice::customprice.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('customprice/customprice/' . $customprice->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/customprice/customprice'))
                ->redirect();
        }

    }

    /**
     * Show customprice for editing.
     *
     * @param Request $request
     * @param Model   $customprice
     *
     * @return Response
     */
    public function edit(CustompriceRequest $request, Customprice $customprice)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('customprice::customprice.name'))
            ->view('customprice::customprice.edit', true)
            ->data(compact('customprice'))
            ->output();
    }

    /**
     * Update the customprice.
     *
     * @param Request $request
     * @param Model   $customprice
     *
     * @return Response
     */
    public function update(CustompriceRequest $request, Customprice $customprice)
    {
        try {
            $attributes = $request->all();

            $customprice->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('customprice::customprice.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('customprice/customprice/' . $customprice->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('customprice/customprice/' . $customprice->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the customprice.
     *
     * @param Model   $customprice
     *
     * @return Response
     */
    public function destroy(CustompriceRequest $request, Customprice $customprice)
    {
        try {

            $customprice->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('customprice::customprice.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('customprice/customprice/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('customprice/customprice/' . $customprice->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple customprice.
     *
     * @param Model   $customprice
     *
     * @return Response
     */
    public function delete(CustompriceRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('customprice::customprice.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('customprice/customprice'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/customprice/customprice'))
                ->redirect();
        }

    }

    /**
     * Restore deleted customprices.
     *
     * @param Model   $customprice
     *
     * @return Response
     */
    public function restore(CustompriceRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('customprice::customprice.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/customprice/customprice'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/customprice/customprice/'))
                ->redirect();
        }

    }

}
